<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="627"/>
        <source>Field</source>
        <translation>Champ</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="627"/>
        <source>Field name</source>
        <translation>Nom du champ</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="628"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="628"/>
        <source>Field description</source>
        <translation>Description du champ</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="629"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="629"/>
        <source>Field value</source>
        <translation>Valeur du champ</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="59"/>
        <source>Exit on closing</source>
        <translation>Quitter à la fermeture</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="60"/>
        <source>Remember Position</source>
        <translation>Se souvenir de la position</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="68"/>
        <source>Host Name Lookup</source>
        <translation>Recherche du nom d&apos;hôte</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="69"/>
        <source>Service Name Lookup</source>
        <translation>Recherche du nom de service</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="75"/>
        <source>Disclosure Triangles</source>
        <translation>Triangles de divulgation</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="76"/>
        <source>Branch Lines</source>
        <translation>Embranchements</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="82"/>
        <source>Auto Save Settings on Exit</source>
        <translation>Enregistrement automatique des paramètres à la fermeture</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="83"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>Sélection : copier les PIDs dans le Presse-papiers</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="85"/>
        <source>Normalize NICE</source>
        <translation>Normaliser NICE</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Use pmap for Map Names</source>
        <translation>Utiliser pmap pour les noms de carte</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="106"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="634"/>
        <source>Linear</source>
        <translation>Linéaire</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="637"/>
        <source>Tree</source>
        <translation>Arborescence</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="646"/>
        <source>Thread</source>
        <translation>Thread</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="653"/>
        <source>All Processes</source>
        <translation>Tous les processus</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="654"/>
        <source>Your Processes</source>
        <translation>Vos processus</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="655"/>
        <source>Non-Root Processes</source>
        <translation>Processus non root</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="656"/>
        <source>Running Processes</source>
        <translation>Processus en cours d&apos;exécution</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="672"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Pause (Ctrl+Espace)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>Processus %1 ( %2 ) - détails</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>Fichiers</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>Cartes de mémoire</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>Environnement</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>Tous les champs</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="579"/>
        <source>Variable</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="579"/>
        <source>Variable name</source>
        <translation>Nom de la variable</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="580"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="580"/>
        <source>Variable value</source>
        <translation>Valeur de la variable</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>Choisir les champs personnalisés </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="75"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="495"/>
        <source>Fd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="495"/>
        <source>File descriptor</source>
        <translation>Descripteur de fichier</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="497"/>
        <source>Mode</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="497"/>
        <source>Open mode</source>
        <translation>Mode ouvert</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="499"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="499"/>
        <source>File name (if available)</source>
        <translation>Nom de fichier (si disponible)</translation>
    </message>
</context>
<context>
    <name>IO_Graph</name>
    <message>
        <location filename="../infobar.cpp" line="785"/>
        <source>I/O Summary:</source>
        <translation>Résumé des I/O&#xa0;:</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="819"/>
        <source>No input or output</source>
        <translation>Aucune entrée ou sortie</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="43"/>
        <source>Change Update Period</source>
        <translation>Changer la fréquence de mise à jour</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="49"/>
        <source>New Update Period</source>
        <translation>Nouvelle fréquence de mise à jour</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="85"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="87"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="121"/>
        <source>No UPDATE</source>
        <translation>Pas de MISE À JOUR</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="139"/>
        <source>Invalid value</source>
        <translation>Valeur invalide</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Address Range</source>
        <translation>Plage d&apos;adresses</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Mapped addresses (hex) )</source>
        <translation>Adresses mappées (hex))</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Kbytes mapped (dec)</source>
        <translation>Koctets mappés (déc.))</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Perm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Permission flags</source>
        <translation>Flags de permission</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>Offset</source>
        <translation>Décalage</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>Décalage de fichier au début du mappage (hex)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Device</source>
        <translation>Dispositif</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation>Chiffres majeurs et mineurs des dispositifs (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode</source>
        <translation>Nœud d&apos;index</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode number (dec)</source>
        <translation>Numéro du nœud d&apos;index (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File name (if available)</source>
        <translation>Nom de fichier (si disponible)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="264"/>
        <source>Permission</source>
        <translation>Autorisation</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Root password</source>
        <translation>Mot de passe root</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="283"/>
        <source>OK</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="150"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="157"/>
        <source>Setting</source>
        <translation>Paramétrage</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="191"/>
        <source>%CPU divided by</source>
        <translation>%CPU divisé par</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="198"/>
        <source>Total cpu: %1</source>
        <translation>Total cpu : %1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="199"/>
        <source>Single cpu: 1</source>
        <translation>CPU unique : 1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="205"/>
        <source>default</source>
        <translation>défaut</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="206"/>
        <source>for developer</source>
        <translation>pour développeur</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="240"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="2615"/>
        <source>PID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2615"/>
        <source>Process ID</source>
        <translation>ID de processus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2617"/>
        <source>TGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2617"/>
        <source>Task group ID ( parent of threads )</source>
        <translation>ID de groupe de tâches ( parent de threads )</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2619"/>
        <source>PPID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2619"/>
        <source>Parent process ID</source>
        <translation>ID du processus parent</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2621"/>
        <source>PGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2621"/>
        <source>Process group ID</source>
        <translation>ID de groupe de processus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2623"/>
        <source>SID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2623"/>
        <source>Session ID</source>
        <translation>ID de session</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2625"/>
        <source>TTY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2625"/>
        <source>Terminal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2627"/>
        <source>TPGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2627"/>
        <source>Process group ID of tty owner</source>
        <translation>ID du groupe de processus du propriétaire tty</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2629"/>
        <source>USER</source>
        <translation>UTILISATEUR</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2629"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>Propriétaire (*=suid root, +=suid utilisateur)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2631"/>
        <source>GROUP</source>
        <translation>GROUPE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2631"/>
        <source>Group name (*=sgid other)</source>
        <translation>Nom de groupe (*=sgid autre)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2633"/>
        <source>UID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2633"/>
        <source>Real user ID</source>
        <translation>ID d&apos;utilisateur réel</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2635"/>
        <source>EUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2635"/>
        <source>Effective user ID</source>
        <translation>ID d&apos;utilisateur effectif</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2637"/>
        <source>SUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2637"/>
        <source>Saved user ID (Posix)</source>
        <translation>ID d&apos;utilisateur sauvegardé (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2639"/>
        <source>FSUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2639"/>
        <source>File system user ID</source>
        <translation>ID utilisateur du système de fichiers</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2641"/>
        <source>GID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2641"/>
        <source>Real group ID</source>
        <translation>ID de groupe réel</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2643"/>
        <source>EGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2643"/>
        <source>Effective group ID</source>
        <translation>ID de groupe effectif</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2645"/>
        <source>SGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2645"/>
        <source>Saved group ID (Posix)</source>
        <translation>ID de groupe sauvegardé (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2647"/>
        <source>FSGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2647"/>
        <source>File system group ID</source>
        <translation>ID de groupe de système de fichiers</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2649"/>
        <source>PRI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2649"/>
        <source>Dynamic priority</source>
        <translation>Priorité dynamique</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2651"/>
        <source>NICE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2651"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation>Faveur de planification (temps élevé -&gt; moins de temps CPU)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2653"/>
        <source>NLWP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2653"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>Nombre de tâches (threads) dans le groupe de tâches</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2655"/>
        <source>PLCY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2655"/>
        <source>Scheduling policy</source>
        <translation>Type d&apos;ordonnancement</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2657"/>
        <source>RPRI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2657"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>Priorité temps réel (0-99, avantage au plus élevé)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2659"/>
        <source>TMS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2659"/>
        <source>Time slice in milliseconds</source>
        <translation>Tranche de temps en millisecondes</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2661"/>
        <source>%SAVG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2661"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation>Pourcentage de temps moyen de sommeil (-1 -&gt; N/A)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2663"/>
        <source>CPUSET</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2663"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation>Masque d&apos;affinité de CPU (0 -&gt; API non supportée)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2665"/>
        <source>MAJFLT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2665"/>
        <source>Number of major faults (disk access)</source>
        <translation>Nombre d&apos;échecs majeurs (accès disque)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2667"/>
        <source>MINFLT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2667"/>
        <source>Number of minor faults (no disk access)</source>
        <translation>Nombre de défauts mineurs (pas d&apos;accès au disque)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>VSIZE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>Virtual image size of process</source>
        <translation>Taille de l&apos;image virtuelle du processus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2672"/>
        <source>RSS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2672"/>
        <source>Resident set size</source>
        <translation>Taille de l&apos;ensemble résident</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2674"/>
        <source>MEM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2674"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>Utilisation mémoire (RSS-SHARE)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2676"/>
        <source>TRS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2676"/>
        <source>Text(code) resident set size</source>
        <translation>Texte (code) taille du groupe de résidents</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2678"/>
        <source>DRS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2678"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation>Taille de l&apos;ensemble de données résidant (malloc+variable globale)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2680"/>
        <source>STACK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2680"/>
        <source>Stack size</source>
        <translation>Taille de la pile</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2682"/>
        <source>SHARE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2682"/>
        <source>Shared memory with other libs</source>
        <translation>Mémoire partagée avec d&apos;autres bibliothèques</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2684"/>
        <source>SWAP</source>
        <translation>ÉCHANGE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2684"/>
        <source>Kbytes on swap device</source>
        <translation>Koctets sur le périphérique d&apos;échange</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2686"/>
        <source>IO_R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2686"/>
        <source>io read (file)</source>
        <translation>io en lecture (fichier)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2688"/>
        <source>IO_W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2688"/>
        <source>io write (file)</source>
        <translation>io en écriture (fichier)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2690"/>
        <source>DT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2690"/>
        <source>Number of dirty (non-written) pages</source>
        <translation>Nombre de pages &quot;sales&quot; (non écrites)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2692"/>
        <source>STAT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2692"/>
        <source>State of the process </source>
        <translation>État du processus </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2694"/>
        <source>FLAGS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2694"/>
        <source>Process flags (hex)</source>
        <translation>Flags de processus (hex)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2696"/>
        <source>WCHAN</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2696"/>
        <source>Kernel function where process is sleeping</source>
        <translation>Fonction du noyau où le processus est en sommeil</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2698"/>
        <source>%WCPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2698"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation>Pourcentage pondéré de CPU (30 s en moyenne)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2700"/>
        <source>%CPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2700"/>
        <source>Percentage of CPU used since last update</source>
        <translation>Pourcentage du CPU utilisé depuis la dernière mise à jour</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2702"/>
        <source>%MEM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2702"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation>Pourcentage de mémoire utilisé (RSS/total mem)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2704"/>
        <source>START</source>
        <translation>DÉBUT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2704"/>
        <source>Time process started</source>
        <translation>Moment de démarrage du processus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2706"/>
        <source>TIME</source>
        <translation>TEMPS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2706"/>
        <source>Total CPU time used since start</source>
        <translation>Temps total de CPU utilisé depuis le démarrage</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2708"/>
        <source>CPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2708"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation>CPU sur laquelle le processus s&apos;exécute (système SMP)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2710"/>
        <source>the process name</source>
        <translation>le nom du processus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2710"/>
        <source>Process Name</source>
        <translation>Nom du processus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2714"/>
        <source>CWD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2714"/>
        <source>Current working directory</source>
        <translation>Répertoire courant</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2715"/>
        <source>ROOT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2715"/>
        <source>Root directory of process</source>
        <translation>Répertoire racine du processus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>COMMAND_LINE</source>
        <translation>LIGNE_DE_COMMANDE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>Command line that started the process</source>
        <translation>Ligne de commande qui a lancé le processus</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="1628"/>
        <source>Show</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1631"/>
        <source>Hide</source>
        <translation>Cacher</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1636"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="437"/>
        <source>User: </source>
        <translation>Utilisateur&#xa0;: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="438"/>
        <source>System: </source>
        <translation>Système&#xa0;: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>Nice: </source>
        <translation>Priorité : </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="437"/>
        <location filename="../infobar.cpp" line="438"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="474"/>
        <location filename="../infobar.cpp" line="509"/>
        <source>Total: </source>
        <translation>Total : </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="477"/>
        <location filename="../infobar.cpp" line="515"/>
        <source>Used: </source>
        <translation>Utilisé&#xa0;: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="481"/>
        <source>Cached: </source>
        <translation>Caché&#xa0;: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="484"/>
        <source>Buffer: </source>
        <translation>Tampon : </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="512"/>
        <source>Free: </source>
        <translation>Libre&#xa0;: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="554"/>
        <source>Time passed after system boot</source>
        <translation>Temps écoulé après le démarrage du système</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="582"/>
        <source>Average CPU load each 1, 5 ,15 minutes</source>
        <translation>Charge moyenne du CPU toutes les 1, 5 ,15 minutes</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="727"/>
        <source>CPU Usage Summary:</source>
        <translation>Résumé de l&apos;utilisation du CPU :</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="171"/>
        <source>header_popup</source>
        <translation>en-tête_notification</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="172"/>
        <source>Remove Field</source>
        <translation>Retirer le champ</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="173"/>
        <source>Add Field</source>
        <translation>Ajouter un champ</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="176"/>
        <source>Session</source>
        <translation>Session</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="180"/>
        <source>View</source>
        <translation>Vue</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="181"/>
        <source>Process</source>
        <translation>Processus</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="182"/>
        <source>Log</source>
        <translation>Registre</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="187"/>
        <source>Fields</source>
        <translation>Champ</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="188"/>
        <source>Custom Fields</source>
        <translation>Champs personnalisés</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="190"/>
        <source>Basic Fields </source>
        <translation>Champs de base </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="192"/>
        <source>Jobs Fields </source>
        <translation>Champs d&apos;emplois </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="194"/>
        <source>Memory Fields </source>
        <translation>Champs de mémoire </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="197"/>
        <source>Scheduling Fields </source>
        <translation>Champs ordonnancement </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="214"/>
        <source>Select Custom Fields...</source>
        <translation>Choisir des champs personnalisés...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="223"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="224"/>
        <source>Update Period...</source>
        <translation>Fréquence de mise à jour...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="233"/>
        <source>Show Status bar</source>
        <translation>Afficher la barre de statut</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="242"/>
        <source>Preferences...</source>
        <translation>Préférences...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="248"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="249"/>
        <location filename="../qps.cpp" line="1676"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="330"/>
        <source>test</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="331"/>
        <source>Copied to Clipboard</source>
        <translation>Copié dans le presse-papier</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="383"/>
        <source>context popup</source>
        <translation>contextuel</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="384"/>
        <source>Renice...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="385"/>
        <source>Scheduling...</source>
        <translation>Ordonnancement...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="387"/>
        <source>Terminate</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="388"/>
        <source>Hangup</source>
        <translation>Suspendre</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="389"/>
        <source>Kill</source>
        <translation>Tuer</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="390"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="392"/>
        <source>Continue</source>
        <translation>Continuer</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="395"/>
        <source>Other Signals</source>
        <translation>Autres signaux</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="396"/>
        <source>SIGINT (interrupt)</source>
        <translation>SIGINT (interruption)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="398"/>
        <source>SIGCONT (continue)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="400"/>
        <source>SIGSTOP (stop)</source>
        <translation>SIGSTOP (arrêt)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="402"/>
        <source>SIGQUIT (quit)</source>
        <translation>SIGQUIT (quitter)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="404"/>
        <source>SIGILL (illegal instruction)</source>
        <translation>SIGILL (instruction illégale)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="406"/>
        <source>SIGABRT (abort)</source>
        <translation>SIGABRT (avorter)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="408"/>
        <source>SIGFPE (floating point exception)</source>
        <translation>SIGFPE (Erreur sur un nombre flottant)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="410"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation>SIGSEGV (violation de segmentation)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="412"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation>SIGPIPE (Erreur de tube)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="414"/>
        <source>SIGALRM (timer signal)</source>
        <translation>SIGALRM (signal d&apos;alarme)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="416"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation>SIGUSR1 (défini par l&apos;utilisateur 1)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="418"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation>SIGUSR2 (défini par l&apos;utilisateur 2)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="420"/>
        <source>SIGCHLD (child death)</source>
        <translation>SIGCHLD (Processus enfant terminé ou stoppé )</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="422"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation>SIGTSTP (arrêt de tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="424"/>
        <source>SIGTTIN (tty input)</source>
        <translation>SIGTTIN (entrée tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="426"/>
        <source>SIGTTOU (tty output)</source>
        <translation>SIGTTOU (sortie tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="433"/>
        <source>View Details</source>
        <translation>Voir les détails</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="671"/>
        <source>Show File Path</source>
        <translation>Afficher le chemin du fichier</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="677"/>
        <source>Show Graph</source>
        <translation>Afficher le Graphique</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="683"/>
        <source>Show Control Bar</source>
        <translation>Afficher la barre de contrôle</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="694"/>
        <source>Include Child Times</source>
        <translation>Inclure le temps des enfants</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="282"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1139"/>
        <location filename="../qps.cpp" line="1170"/>
        <location filename="../qps.cpp" line="1177"/>
        <location filename="../qps.cpp" line="1198"/>
        <location filename="../qps.cpp" line="1232"/>
        <location filename="../qps.cpp" line="1327"/>
        <source>Permission denied</source>
        <translation>Permission refusée</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1140"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation>Vous n&apos;avez pas la permission de recommencer les processus sélectionnés. Seuls le propriétaire du processus et le super-utilisateur sont autorisés à le faire.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1171"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation>Vous n&apos;êtes pas autorisé à exécuter le processus %1 (%2). Seuls le propriétaire du processus et le super-utilisateur sont autorisés à le faire.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1178"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation>Seul le super-utilisateur peut réduire la valeur de transaction d&apos;un processus.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1199"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation>Seul le super-utilisateur peut modifier la stratégie d&apos;ordonnancement et la priorité statique.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1233"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation>Vous n&apos;avez pas la permission de changer l&apos;ordonnancement et/ou la priorité du processus %1 (%2). Seul le super-utilisateur en a le droit.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1294"/>
        <source>Do you really want to terminate the selected process(es)?</source>
        <translation>Voulez-vous vraiment mettre fin au(x) processus sélectionné(s) ?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1296"/>
        <source>Do you really want to hang up the selected process(es)?</source>
        <translation>Voulez-vous vraiment suspendre le ou les processus sélectionnés ?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1298"/>
        <source>Do you really want to kill the selected process(es)?</source>
        <translation>Voulez-vous vraiment tuer le(s) processus sélectionné(s) ?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1307"/>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1328"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation>Vous n&apos;êtes pas autorisé à envoyer un signal pour traiter %1 (%2). Seuls le super-utilisateur et le propriétaire du processus peuvent lui envoyer des signaux.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1692"/>
        <source>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1694"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</source>
        <translation>&lt;h2&gt; Qps %1 - Un gestionnaire de processus visuel &lt;/h2&gt; %2 utilisant les bibliothèqhes Qt %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source : &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker : &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1714"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation>&lt;b&gt;Origine de Qps par&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributeurs&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Change scheduling</source>
        <translation>Changer l&apos;ordonnancement</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="296"/>
        <source>Scheduling Policy</source>
        <translation>Politique d&apos;ordonnancement</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="298"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation>SCHED_OTHER (en temps partagé)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="299"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation>SCHED_FIFO (temps réel)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="300"/>
        <source>SCHED_RR (real-time)</source>
        <translation>SCHED_RR (temps réel)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="314"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="316"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="346"/>
        <source>Priority (1-99):</source>
        <translation>Priorité (1-99) :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="379"/>
        <source>Invalid Input</source>
        <translation>Entrée invalide</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="380"/>
        <source>The priority must be in the range 1..99</source>
        <translation>La priorité doit se situer dans la plage 1..99</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="588"/>
        <source>PID, COMMAND, USER...</source>
        <translation>PID, COMMANDE, UTILISATEUR ...</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="589"/>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="179"/>
        <source>Renice Process</source>
        <translation>Processus Renice</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>New nice value:</source>
        <translation>Nouvelle nice valeur :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="225"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="229"/>
        <source>OK</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>Fd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>File descriptor</source>
        <translation>Descripteur de fichier</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Proto</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>Protocole (TCP ou UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Recv-Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Bytes in receive queue</source>
        <translation>Octets dans la file de réception</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Send-Q</source>
        <translation>Send-Q (envoyer)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Bytes in send queue</source>
        <translation>Octets dans la file d&apos;émission</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local Addr</source>
        <translation>Adresse locale</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local IP address</source>
        <translation>Adresse IP Locale</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <location filename="../details.cpp" line="154"/>
        <source>Port</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Local port</source>
        <translation>Port local</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote Addr</source>
        <translation>Adresse distante</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote IP address</source>
        <translation>Adresse IP distante</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Remote port</source>
        <translation>Port distant</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>State</source>
        <translation>État</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Connection state</source>
        <translation>État de la connexion</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="624"/>
        <source>Process count: %1</source>
        <translation>Nombre de processus : %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="343"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation> C&apos;est une fonctionnalité alpha instable
 Vous voyez peut-être un SEGFAULT...</translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="485"/>
        <source>title</source>
        <translation>titre</translation>
    </message>
</context>
</TS>
